==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/benefity/pohybbenefitudbrecord.php <==
<?php
/**
 * pavel.rudol, 25.5.2022 15:30
 */

namespace RonPortal\Benefity;

use Ron\DateUtils;
use Ron\TextManager;
use RonPortal\RonPortalDBRecord;
use RonPortal\System\AgentManager;
use RonPortal\User;

class PohybBenefituDBRecord extends RonPortalDBRecord
{
    public function __construct($database, $logDescription = 'Intraweb')
    {
        parent::__construct($database, 'PohybBenefitu', $logDescription);

//        $this->addDateField('DatumVlozeni', true, DateUtils::today());
        $this->addStringField('RC', true, 15); 

        $this->addDateField('DatumSchvaleni');
        $this->addStringField('Schvalil', false, 25, User::getLoginName());

        $this->addStringField('Cerpani_Username', false, 25, User::getLoginName());
        $this->addDateField('DatumCerpani');
    }

    /**
     * @param PohybBenefitu $pohyb
     * @return static
     */
    public static function loadFromObject($database, $pohyb)
    {
        $rec = new static($database);

        $rec->findFieldByName('RC')->setNewValue($pohyb->rc);
        $rec->findFieldByName('DatumVlozeni')->setNewValue($pohyb->datumVlozeni);
        $rec->findFieldByName('DatumSchvaleni')->setNewValue($pohyb->datumSchvaleni);
        $rec->findFieldByName('Schvalil')->setNewValue($pohyb->schvalil);
        $rec->findFieldByName('Cerpani_Username')->setNewValue($pohyb->cerpaniUserName);
        $rec->findFieldByName('DatumCerpani')->setNewValue($pohyb->datumCerpani);

        $rec->addIntField('DruhPohybu')->setNewValue($pohyb->druhPohybu);
        $rec->addIntField('IDBenefitu')->setNewValue($pohyb->rc);
        $rec->addIntField('ID')->setNewValue($pohyb->id);
        $rec->addDateField('DatumRezervaceDo')->setNewValue($pohyb->datumRezervaceDo);
        $rec->addDateField('DatumOmezeniPlatnosti')->setNewValue($pohyb->datumOmezeniPlatnosti);
        $rec->addIntField('PocetBodu')->setNewValue($pohyb->pocetBodu);
        $rec->addIntField('PocetBenefitu')->setNewValue($pohyb->pocetBenefitu);
        $rec->addIntField('TypDoplatku')->setNewValue($pohyb->typDoplatku);
        $rec->addIntField('DoplatekCastka')->setNewValue($pohyb->doplatekCastka);
        $rec->addMemoField('Poznamka')->setNewValue($pohyb->poznamka);

        return $rec;
    }
    
    public function setSchvaleni()
    {
        $fSchvaleni = $this->findFieldByName('DatumSchvaleni');
        if (!$fSchvaleni->value) {
            $fSchvaleni->setNewValue(DateUtils::today());
            $this->findFieldByName('Schvalil')->setNewValue(User::getLoginName());
        }
    }
    
    public function setVydani()
    {
        $fCerpani = $this->findFieldByName('DatumCerpani');
        if (!$fCerpani->value) {
            $fCerpani->setNewValue(DateUtils::today());
            $this->findFieldByName('Cerpani_Username')->setNewValue(User::getLoginName());
        }
    }

    public function checkConditions()
    {
        $benefit = Benefit::nactiBenefit($this->database, $this['IDBenefitu']);

        if ($benefit->maxPocetJedenZam) {
            if ($this['PocetBenefitu'] > $benefit->maxPocetJedenZam) {
                throw new \Exception(TextManager::_('prekrocen_pocet_na_osobu'));
            }
        }
    }

    public function runAgent()
    {
        $this->checkConditions();

        //50 - Kontrola benefitu
        $params = 50 .
            ' -BenefitRC:' . $this['RC'] .
            ' -BenefitDruhPohybu:' . $this['DruhPohybu'] .
            ' -BenefitID:' . $this['IDBenefitu'] . 
            ' -BenefitIDPohybu:' . ($this['ID']) .
            ' -BenefitDatumSchvaleni:' . ($this['DatumSchvaleni'] ? date('Y-m-d', $this['DatumSchvaleni']) : '') .
            ' -BenefitDatumRezervaceDo:' . ($this['DatumRezervaceDo'] ? date('Y-m-d', $this['DatumRezervaceDo']) : '') .
            ' -BenefitDatumCerpani:' . ($this['DatumCerpani'] ? date('Y-m-d', $this['DatumCerpani']) : '') .
            ' -BenefitCerpaniUsername:' . $this['Cerpani_Username'] .
            ' -BenefitDatumVlozeni:' . ($this['DatumVlozeni'] ? date('Y-m-d', $this['DatumVlozeni']) : '') .
            ' -BenefitDatumOmezeniPlatnosti:' . ($this['DatumOmezeniPlatnosti'] ? date('Y-m-d', $this['DatumOmezeniPlatnosti']) : "") .
            ' -BenefitPocetBodu:' . $this['PocetBodu'] .
            ' -BenefitPocet:' . $this['PocetBenefitu'] .
            ' -BenefitDruhZdroje:' . PohybBenefitu::DRUH_ZDROJE_PORTAL . //RON portal
            ' -BenefitTypDoplatku:' . $this['TypDoplatku'] .
            ' -BenefitDoplatekCastka:' . $this['DoplatekCastka'] .
            ' -BenefitPoznamka:"' . $this['Poznamka'] .
            '" ';

        AgentManager::executePersonAgent($params);
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/benefity/pohybbenefitudbrecord.php <==
<?php
/**
 * pavel.rudol, 25.5.2022 15:30
 */

namespace RonPortal\Benefity;

use Ron\DateUtils;
use Ron\TextManager;
use RonPortal\RonPortalDBRecord;
use RonPortal\System\AgentManager;
use RonPortal\User;

class PohybBenefituDBRecord extends RonPortalDBRecord
{
    public function __construct($database, $logDescription = 'Intraweb')
    {
        parent::__construct($database, 'PohybBenefitu', $logDescription);

        $this->addDateField('DatumVlozeni', true, DateUtils::today());
        $this->addStringField('RC', true, 15); 

        $this->addDateField('DatumSchvaleni');
        $this->addStringField('Schvalil', false, 25, User::getLoginName());

        $this->addStringField('Cerpani_Username', false, 25, User::getLoginName());
        $this->addDateField('DatumCerpani');
    }

    /**
     * @param PohybBenefitu $pohyb
     * @return static
     */
    public static function loadFromObject($database, $pohyb)
    {
        $rec = new static($database);

        $rec->findFieldByName('RC')->setNewValue($pohyb->rc);
        $rec->findFieldByName('DatumVlozeni')->setNewValue($pohyb->datumVlozeni);
        $rec->findFieldByName('DatumSchvaleni')->setNewValue($pohyb->datumSchvaleni);
        $rec->findFieldByName('Schvalil')->setNewValue($pohyb->schvalil);
        $rec->findFieldByName('Cerpani_Username')->setNewValue($pohyb->cerpaniUserName);
        $rec->findFieldByName('DatumCerpani')->setNewValue($pohyb->datumCerpani);

        $rec->addIntField('DruhPohybu')->setNewValue($pohyb->druhPohybu);
        $rec->addIntField('IDBenefitu')->setNewValue($pohyb->rc);
        $rec->addIntField('ID')->setNewValue($pohyb->id);
        $rec->addDateField('DatumRezervaceDo')->setNewValue($pohyb->datumRezervaceDo);
        $rec->addDateField('DatumOmezeniPlatnosti')->setNewValue($pohyb->datumOmezeniPlatnosti);
        $rec->addIntField('PocetBodu')->setNewValue($pohyb->pocetBodu);
        $rec->addIntField('PocetBenefitu')->setNewValue($pohyb->pocetBenefitu);
        $rec->addIntField('TypDoplatku')->setNewValue($pohyb->typDoplatku);
        $rec->addIntField('DoplatekCastka')->setNewValue($pohyb->doplatekCastka);
        $rec->addMemoField('Poznamka')->setNewValue($pohyb->poznamka);

        return $rec;
    }
    
    public function setSchvaleni()
    {
        $fSchvaleni = $this->findFieldByName('DatumSchvaleni');
        if (!$fSchvaleni->value) {
            $fSchvaleni->setNewValue(DateUtils::today());
            $this->findFieldByName('Schvalil')->setNewValue(User::getLoginName());
        }
    }
    
    public function setVydani()
    {
        $fCerpani = $this->findFieldByName('DatumCerpani');
        if (!$fCerpani->value) {
            $fCerpani->setNewValue(DateUtils::today());
            $this->findFieldByName('Cerpani_Username')->setNewValue(User::getLoginName());
        }
    }

    public function checkConditions()
    {
        $benefit = Benefit::nactiBenefit($this->database, $this['IDBenefitu']);

        if (!$benefit->neomezenyPocetJedenZam && $benefit->maxPocetJedenZam) {
            if ($this['PocetBenefitu'] > $benefit->maxPocetJedenZam) {
                throw new \Exception(TextManager::_('prekrocen_pocet_na_osobu'));
            }
        }
    }

    public function runAgent()
    {
        $this->checkConditions();

        //50 - Kontrola benefitu
        $params = 50 .
            ' -BenefitRC:' . $this['RC'] .
            ' -BenefitDruhPohybu:' . $this['DruhPohybu'] .
            ' -BenefitID:' . $this['IDBenefitu'] . 
            ' -BenefitIDPohybu:' . ($this['ID']) .
            ' -BenefitDatumSchvaleni:' . ($this['DatumSchvaleni'] ? date('Y-m-d', $this['DatumSchvaleni']) : '') .
            ' -BenefitDatumRezervaceDo:' . ($this['DatumRezervaceDo'] ? date('Y-m-d', $this['DatumRezervaceDo']) : '') .
            ' -BenefitDatumCerpani:' . ($this['DatumCerpani'] ? date('Y-m-d', $this['DatumCerpani']) : '') .
            ' -BenefitCerpaniUsername:' . $this['Cerpani_Username'] .
            ' -BenefitDatumVlozeni:' . ($this['DatumVlozeni'] ? date('Y-m-d', $this['DatumVlozeni']) : '') .
            ' -BenefitDatumOmezeniPlatnosti:' . ($this['DatumOmezeniPlatnosti'] ? date('Y-m-d', $this['DatumOmezeniPlatnosti']) : "") .
            ' -BenefitPocetBodu:' . $this['PocetBodu'] .
            ' -BenefitPocet:' . $this['PocetBenefitu'] .
            ' -BenefitDruhZdroje:' . PohybBenefitu::DRUH_ZDROJE_PORTAL . //RON portal
            ' -BenefitTypDoplatku:' . $this['TypDoplatku'] .
            ' -BenefitDoplatekCastka:' . $this['DoplatekCastka'] .
            ' -BenefitPoznamka:"' . $this['Poznamka'] .
            '" ';

        AgentManager::executePersonAgent($params);
    }

}
